"""This is the nester.py module and it provides one function called print_lol
which prints lists that may or may not include nested lists"""
import sys
def print_lol(the_list,indent=False,level=0,fh=sys.stdout):
    """This functions takes an argument called the_list and print it on screen.
    if the_list is nested, it will be recursively exhausted and printed out """
    for each_item in the_list:
        if isinstance(each_item,list):
            print_lol(each_item,indent,level+1,fh)
        else:
            if indent:
                for tab_stop in range(level):
                    print("\t",end='',file=fh)
            print(each_item,end='',file=fh)
